import { useEffect } from "react";
import usePrevious from "../src/hooks/usePrevious.js";
import { useSetState } from "../src/hooks/useSetState.js";
import styles from "./Weather.module.js";
import Cloudy from "./cloudy/Cloudy.js";
import Nighty from "./nighty/Nighty.js";
import Rainy from "./rainy/Rainy.js";
import Snowy from "./snowy/Snowy.js";
import Sunny from "./sunny/Sunny.js";
import { jsxs, jsx } from "../_virtual/jsx-runtime.js";
const WeatherTypeStore = {
  ["sunny"]: {
    class: styles["weather-sunny"],
    component: Sunny
  },
  ["cloudy"]: {
    class: styles["weather-cloudy"],
    component: Cloudy
  },
  ["rainy"]: {
    class: styles["weather-rainy"],
    component: Rainy
  },
  ["snowy"]: {
    class: styles["weather-snowy"],
    component: Snowy
  },
  ["nighty"]: {
    class: styles["weather-nighty"],
    component: Nighty
  }
};
const Weather = ({
  type,
  duration = 3600,
  iconDuration,
  className = ""
}) => {
  const {
    class: typeClassName,
    component: Component
  } = WeatherTypeStore[type];
  const preType = usePrevious(type);
  const {
    component: PreComponent
  } = WeatherTypeStore[preType || type];
  const [animates, setAnimates] = useSetState({
    preClassName: "",
    curClassName: ""
  });
  useEffect(() => {
    if (!preType) {
      return;
    }
    setAnimates({
      preClassName: "animate__fadeOut",
      curClassName: "animate__fadeIn"
    });
  }, [preType, type, setAnimates]);
  const style = {
    "--animate-duration": `${iconDuration != null ? iconDuration : duration / 2}ms`
  };
  return /* @__PURE__ */ jsxs("div", {
    className: `${styles["weather-container"]} ${typeClassName} ${className}`,
    style,
    children: [preType ? /* @__PURE__ */ jsx(PreComponent, {
      className: `animate__animated ${animates.preClassName}`
    }) : null, /* @__PURE__ */ jsx(Component, {
      className: `animate__animated ${animates.curClassName}`
    })]
  });
};
export { Weather as default };
